@@ -1,11 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "auth-source-keytar" "0.1.3"
+(define-package "auth-source-keytar" "20251231.1726"
   "Integrate auth-source with keytar."
   '((emacs  "24.4")
     (keytar "0.1.2")
     (s      "1.12.0"))
   :url "https://github.com/emacs-grammarly/auth-source-keytar"
-  :commit "6edf8ec86d74f1e9853da23052291cc28d2df8bc"
-  :revdesc "6edf8ec86d74"
+  :commit "ae32dd807aa3cff59e4384ce8c9d7de259e45998"
+  :revdesc "ae32dd807aa3"
+  :keywords '("convenience" "keytar" "password" "credential" "secret" "security")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
